;|
*******************************************************************
*                                                                 *
* Wir sind das "Express-Tools 2 German Project"                   *
* Nachfolgend nur noch abgekrzt durch "ET2GP" !                  *
* --------------------------------------------------------------- *
* Die Beteiligten in alphabetischer Reihenfolge:                  *
*                                                                 *
* Vorname, Name         E-Mail-Adresse          Website           *
* --------------------------------------------------------------- *
* Holger Brischke       kontakt@defun.de        www.defun.de      *
* Martin Drese          drese@defun.de          keine Website     *
* Markus Hoffmann       hoffmann@defun.de       keine Website     *
* Marc Scherer          marc.scherer@zvo.com    keine Website     *
* Peter Tropf           info@petertropf.de      keine Website     *
*                                                                 *
* Special Guest (bersetzung der Hilfe-Texte)                     *
* Walter Verburg        walterverburg@web.de    keine Website     *
*                                                                 *
*******************************************************************

***ET2GP-Anpassung*** -> Kommentar
Diese bersetzung der Express-Tools fr AutoCAD 2004 basiert auf den
originalen, mit AutoCAD 2004 gelieferten Express-Tools von Autodesk.
Da nicht jeder deutsch-sprachige User von AutoCAD des Englischen
mchtig ist, haben wir diese bersetzung vorgenommen.

nderungen an den Originaltexten sind immer mit einem einleitenden
Kommentar versehen, wobei die Steuerzeichen fr Kommentare je nach
Dateiart variieren:

Eine nderung an einer Lisp-Datei ist folgendermaen markiert:

;;; ***ET2GP-Anpassung*** ...

Bei einem DCL-File dann so:

/// ***ET2GP-Anpassung*** ...

Originalzeilen bleiben soweit wie mglich erhalten, werden jedoch durch
ein "Auskommentieren" deaktiviert.

Anderweitige Modifikationen, wie z.B. komplett neue Zeilen oder permanent 
deaktivierte Funktionen sind mit einem erklrendem Kommentar versehen.

Beispiel:
...
;;; ***ET2GP-Anpassung*** -> Dialog bersetzt...
         ;_ (prompt "\nSelect object(s) on the layer(s) to be isolated: ")
         (prompt "\nObjekt(e) auf zu isolierenden Layern whlen: ")
...

Jede angepasste Datei wird mit diesem Header vorneweg versehen, wobei die
nachfolgenden Zeilen bezglich der Informationen (wie z.B. Name des bersetzers)
natrlich variabel sind.

***ET2GP-Anpassung*** -> Kommentar
Version 1.0
30.09.2003
Holger Brischke
|;
;;;
;;;    XLIST.LSP
;;;    Copyright  1999 by Autodesk, Inc.
;;;
;;;    Your use of this software is governed by the terms and conditions of the
;;;    License Agreement you accepted prior to installation of this software.
;;;    Please note that pursuant to the License Agreement for this software,
;;;    "[c]opying of this computer program or its documentation except as
;;;    permitted by this License is copyright infringement under the laws of
;;;    your country.  If you copy this computer program without permission of
;;;    Autodesk, you are violating the law."
;;;
;;;    AUTODESK PROVIDES THIS PROGRAM "AS IS" AND WITH ALL FAULTS.
;;;    AUTODESK SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTY OF
;;;    MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE.  AUTODESK, INC.
;;;    DOES NOT WARRANT THAT THE OPERATION OF THE PROGRAM WILL BE
;;;    UNINTERRUPTED OR ERROR FREE.
;;;
;;;    Use, duplication, or disclosure by the U.S. Government is subject to
;;;    restrictions set forth in FAR 52.227-19 (Commercial Computer
;;;    Software - Restricted Rights) and DFAR 252.227-7013(c)(1)(ii)
;;;    (Rights in Technical Data and Computer Software), as applicable.
;;;
;;;  ----------------------------------------------------------------
 
;;;  DESCRIPTION
;;;
;;;   XLIST
;;;   This routine lists certain properties of objects that are nested in
;;;   a block or xref.
;;;
;;;   (c:xlist) and (c:-xlist) call (XLIST) with a boolean kUseDialog turned on
;;; to use the dialog display or off for listing at the command line, respectively.
;;;
;;;   (XLIST)
;;;   This is the main function called from the command line.  This function
;;;   prompts the user to pick an object, determines if the selection is valid,
;;;   and if it is, calls GetList().  After calling this function, it calls (DisplayDialog)
;;;   if kUseDialog is true or (DisplayList) if it is false.
;;;
;;;   (GetList)
;;;   This function take the object handle as an argument and parses out the assoc
;;;   codes we are interested in, makes adjustments for the optional codes, converts
;;;   color numbers 1 through 8 back to their color names.  It calls a "vertex" a polyline
;;;   and an "insert" a block.
;;;
;;;   (DisplayDialog)
;;;   It loads XLIST.DCL and sets the keys to the results from GetList() and
;;;   invokes the appropriate dialog to display the results.  I have defined three
;;;   different dialogs depending on the type of object: a dialog to display blocks,
;;;   one for text and one for everything else.
;;;
;;;   (DisplayList)
;;;   Invokes the text screen and displays the results in list format.
;;;
;;;---------------------------------------------------------------------------;
 
;;(defun xlist_err ( /  )
(defun xlist_err (s)
  (setq *error* old_err)
  (command "_.undo" "_end")
  (if old_cmd (setvar "cmdecho" old_cmd))
  (princ)
  ;(princ "xlist_err was called.")
); exit quietly
 
(defun GetList ( / iNest eList   )
  (setq iNest (length (last ePick)))
 
;The next if statement handles block within blocks. iNest = 1 means no nesting. Since (nentsel) goes all the
;way to the root AutoCAD object we have to traverse back up to the top level of the nesting to get a block name.
  (if (= iNest 1)
    (setq eList (entget (car ePick))) ;then pull the list from the standard nentsel call.
    (setq eList (entget (nth (- iNest 2) (last ePick))))  ;else last last our way back up to the top block definition
  );end if
 
 
;Pull out the assoc codes.
  (setq sLayer (cdr (assoc 8 eList))
                sObjectType (cdr (assoc 0 eList))
        sLineType (cdr (assoc 6 eList))     ; This is optional, we check for it later.
                sColor (cdr (assoc 62 eList))
    sBlockname ""
    sStyleName ""
      ); end setq
 
 
;Check for no linetype override, in which case it is bylayer.
      (if (= sLineType nil) (setq sLineType "Bylayer"))   ;Tidy up the optional DXF codes for linetype
 
 
;If the object is a vertex, call a vertex a polyline
      (if (= "VERTEX" sObjectType) (setq sObjectType "POLYLINE"))
 
;If the object is a block, call an insert a block and find out the block name
  (if (= "INSERT" sObjectType)
    (progn
      (setq   sObjectType "BLOCK"
         sBlockname (cdr (assoc 2 eList))
      )
    );end progn
  );end if
 
;If the object is text or mtext, find out the style name
  (if (or (= "TEXT" sObjectType) (= "MTEXT" sObjectType))
    (setq sStyleName (cdr (assoc 7 eList)))
  );end if
 
; Sort out the colors and assign names to the first 8 plus bylayer and byblock
      (cond ( (= nil sColor) (setq sColor "Bylayer"))
          ( (= 0 sColor) (setq sColor "Byblock"))
            ( (= 1 sColor) (setq sColor "Red"))
            ( (= 2 sColor) (setq sColor "Yellow"))
    ( (= 3 sColor) (setq sColor "Green"))
            ( (= 4 sColor) (setq sColor "Cyan"))
            ( (= 5 sColor) (setq sColor "Blue"))
          ( (= 6 sColor) (setq sColor "Magenta"))
            ( (= 7 sColor) (setq sColor "White"))
            ( (= 256 sColor) (setq sColor "Bylayer"))
            (t (setq sColor (itoa sColor)))
      );end cond
 
;(princ (strcat sLayer sColor sObjectType sLinetype sThickness sStylename sBlockname))  ; for debugging purposes
 
); End GetList
 
 
;This fucntion displays the results in LIST form...
(defun DisplayList (  / )
  (textscr)
  (cond
    ((= "BLOCK" sObjectType)
      (princ    (acet-str-format
                  ;;; ***ET2GP-Anpassung*** -> Info bersetzt
                  ;"\n\tObject:\t%1\n\tBlock name:\t%2"
                  "\n\tObjekt:\t%1\n\tBlock Name:\t%2"
                  sObjectType sBlockname )
      );end princ
 
    );end this condition
    ((or (= "TEXT" sObjectType) (= "MTEXT" sObjectType))
      (princ (acet-str-format
               ;;; ***ET2GP-Anpassung*** -> Info bersetzt
               ;"\n\tObject:\t%1\n\tStyle name:\t%2"
               "\n\tObjekt:\t%1\n\Textstil Name:\t%2"
               sObjectType sStylename )
      );end princ
 
    );end this condition
    ( T
      (princ (acet-str-format
               ;;; ***ET2GP-Anpassung*** -> Info bersetzt
               ;"\n\tObject:\t%1"
               "\n\tObjekt:\t%1"
               sObjectType));end princ
    );end this condition
  ); end cond
 
  (princ (acet-str-format
           ;;; ***ET2GP-Anpassung*** -> Info bersetzt
           ;"\n\tLayer:\t\t%1\n\tColor:\t\t%2\n\tLinetype:\t%3"
           "\n\tLayer:\t\t%1\n\tFarbe:\t\t%2\n\tLinientyp:\t%3"
           sLayer sColor sLinetype ) )
 
);end DisplayList
 
 
 
;This function displays the results in dialog form...
 
;Findfile for the dialog in case it isn't in the bonus/lisp/ directory
(defun DisplayDialog ( /  sAcad sAcadPath sDlgNameAndPath dcl_id  )
 
  (setq sAcad (findfile "acad.exe"))
  (setq sAcadPath (substr sAcad 1 (- (strlen sAcad) 8) ))
 
  (if (< (setq dcl_id (load_dialog "xlist.dcl")) 0)
  (progn
    (if (not (setq sDlgNameAndPath (findfile "xlist.dcl")))
    (progn
      (alert
        ;;; ***ET2GP-Anpassung*** -> Meldung bersetzt
        ;"Can't locate dialog definition file XLIST.DCL.\nCheck your support directories."
        "Kann die Dialogfenster-Datei XLIST.DCL nicht finden.\nSupportpfade prfen!."
        )
      (exit)
    );end progn
    );end if
  );end progn
  );end if
 
;Load the dialog.  If the object is a block, load the block dialog; if it is a text entity, load the text dialog.
  (cond
    ((= "BLOCK" sObjectType) (if (not (new_dialog "xlistblock" dcl_id)) (EXIT)))
      ((or (= "TEXT" sObjectType) (= "MTEXT" sObjectType))(if (not (new_dialog "xlisttext" dcl_id)) (EXIT)))
    ( T (if (not (new_dialog "xlist" dcl_id)) (EXIT) ))
  ); end cond
        (set_tile "sLayer" (strcase sLayer T))
        (set_tile "sColor" sColor)
        (set_tile "sObjectType"  sObjectType )
        (set_tile "sLineType" sLineType )
  (set_tile "sBlockname" sBlockname)
  (set_tile "sStyleName" sStyleName)
 
;If we can't starts the dialog, then bail.
        (if   (= (start_dialog) nil)  (exit));
  (unload_dialog dcl_id);
  (princ)
 
); end DisplayDialog
 
 
 
(defun XLIST (  kUseDialog /  sLayer sObjectType sLineType sColor sBlockname
                              sStyleName ePick old_cmd old_err)
;capture existing settings
    (setq old_cmd (getvar "cmdecho")    ; save current setting of cmdecho
        old_err *error*
    *error* xlist_err
    )
 
  (setvar "cmdecho" 0)
  (command "_.undo" "_be")
 
;The next while loop checks for null or invalid selection.
  (while (or
    (not (setq ePick (nentsel
                       ;;; ***ET2GP-Anpassung*** -> Abfrage bersetzt
                       ;"\nSelect nested xref or block object to list: "
                       "\nVerschachteltes XRef- oder Blockelement whlen: "
                       )))
    (< (length ePick) 3)
    );end or
    (progn  (princ
              ;;; ***ET2GP-Anpassung*** -> Meldung bersetzt
              ;"\nObject was invalid or was not selected."
              "\nKein verschachteltes Objekt gewhlt!"
              ))
  );end while
 
;Extract the information...
      (GetList)
 
;If we are calling from "xlist" use the dialog, else display at command line...
  (if kUseDialog (DisplayDialog) (DisplayList))
  (setq *error* old_err)
  (command "_.undo" "_end")
  (setvar "cmdecho" old_cmd)
  ; princ "normal exit called.")
  (princ)
)
 
(defun c:-xlist ( / kUseDialog )
  (setq kUseDialog nil)
  (xlist kUseDialog)
)
(defun c:xlist ( / kUseDialog )
  (setq kUseDialog T)
  (xlist kUseDialog)
)


(princ)
